<?php

/*
Plugin Name: eduPort Flyout
Plugin URI: http://wordpress.org/plugins/eduport-flyout
Description: An easy way to embedd the eduPort-Flyout on your WordPress site.
Author: POLYPLANET
Author URI: http://polyplanet.de/
Version: 1.2.3
Author URI: 
License: GPL3

Text Domain: eduport-flyout
Domain Path: /languages/
*/

/*  Copyright 2016  POLYPLANET

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

/*
Plugin was generated by WP Plugin Scaffold
https://github.com/mcguffin/wp-plugin-scaffold
Command line args were: `"eduPort" admin settings_page --force`
*/

if ( ! class_exists( 'EduportFlyout' ) ):
class EduportFlyout {
	private $eduport_url = 'https://navigation.eduport.hamburg.de/js.php';
	
	private $is_active = false;
	
	private static $_instance = null;

	/**
	 * Getting a singleton.
	 *
	 * @return object single instance of Eduport
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) )
			self::$_instance = new self();
		return self::$_instance;
	}

	/**
	 * Private constructor
	 */
	private function __construct() {
		add_action( 'plugins_loaded' , array( $this , 'load_textdomain' ) );
		add_action( 'template_redirect' , array( $this , 'set_active' ) );
		add_action( 'wp_footer' , array( $this , 'print_script' ), 1000 );

		register_uninstall_hook( __FILE__ , array( __CLASS__ , 'uninstall' ) );
	}

	/**
	 * Load text domain
	 */
	public function load_textdomain() {
		load_plugin_textdomain( 'eduport-flyout' , false, dirname( plugin_basename( __FILE__ ) ) . '/languages/' );
	}
	/**
	 *  Print Eduport script
	 */
	function print_script() {
		if ( $this->is_active ) {
			$username = get_option('eduport_username');
			$username = trim( $username );

			if ( '@' === $username[0] ) {
				$username = substr( $username, 1 );
			}

			if ( ! preg_match( '/\.hamburg\.de$/', $username ) ) {
				$username = sprintf( '%s.hamburg.de', $username );
			}
			
			$script_url = apply_filters( 'eduport_url', 'https://login.eduport.hamburg.de/idp/profile/Logineo/NavConfig' );
			$script_url = add_query_arg( array(
				'jsonp'				=> 'window.navConfig',
				'currentService'	=> 'home',
				'tenant'			=> $username,
			), $script_url );
			echo '<link rel="stylesheet" type="text/css" href="https://login.eduport.hamburg.de/styles.css">' . "\n";
			echo '<script type="text/javascript" src="https://login.eduport.hamburg.de/logineo-nav.js"></script>'. "\n";
			//*/
			printf('<script type="text/javascript" src="%s"></script>'."\n", esc_url( $script_url ) );
		}
	}

	/**
	 *  Set eduPort Flyout active
	 */
	function set_active() {
		$username		= trim( get_option('eduport_username') );
		$has_username	= ! empty( $username );
		$is_global		= intval( get_option('eduport_global') ) ;
		$is_enabled		= (is_single() || is_singular() ) && get_post_meta( get_the_ID(), '_eduport_enabled', true );
		$is_active		= $has_username && ( $is_global || $is_enabled );
		$this->is_active = apply_filters( 'eduport_is_active', $is_active );
	}


	/**
	 *	
	 */
	public static function uninstall() {
		delete_option( 'eduport_global' );
		delete_option( 'eduport_username' );
	}

}
EduportFlyout::instance();

endif;

if ( is_admin() ) {
	require_once plugin_dir_path(__FILE__) . 'include/class-EduportAdmin.php';
	require_once plugin_dir_path(__FILE__) . 'include/class-EduportSettings.php';
}
